#[repr(u8)]pub enum FlexspiPodfBusy {
FLEXSPI_PODF_BUSY_0 = 0,
FLEXSPI_PODF_BUSY_1 = 1,
}Variants
FLEXSPI_PODF_BUSY_0 = 0
divider is not busy and its value represents the actual division.
FLEXSPI_PODF_BUSY_1 = 1
divider is busy with handshake process with module. The value read in the divider represents the previous value of the division factor, and after the handshake the written value of the flexspi_podf will be applied.
Implementations