nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

PerclkPodfBusy

Enum PerclkPodfBusy 

#[repr(u8)]
pub enum PerclkPodfBusy { PERCLK_PODF_BUSY_0 = 0, PERCLK_PODF_BUSY_1 = 1, }

Variants



PERCLK_PODF_BUSY_0 = 0

divider is not busy and its value represents the actual division.



PERCLK_PODF_BUSY_1 = 1

divider is busy with handshake process with module. The value read in the divider represents the previous value of the division factor, and after the handshake the written value of the perclk_podf will be applied.

Implementations

Source

impl PerclkPodfBusy

pub const fn from_bits(val: u8) -> PerclkPodfBusy

pub const fn to_bits(self) -> u8